# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.ai_assistant_get import AiAssistantGet  # noqa: E501

class TestAiAssistantGet(unittest.TestCase):
    """AiAssistantGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantGet:
        """Test AiAssistantGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantGet`
        """
        model = AiAssistantGet()  # noqa: E501
        if include_optional:
            return AiAssistantGet(
                allow_text = True,
                allow_voice = True,
                approved_urls = [
                    ''
                    ],
                avatar_id = '',
                banned_keywords = [
                    ''
                    ],
                conversation_starter = '',
                conversation_style = 'formal',
                created_at = 56,
                deleted_at = 56,
                function = 'support',
                goals = [
                    chat_server_connector.models.ai_assistant_goal_get.AiAssistantGoalGet(
                        additional_prompt = '', 
                        ai_assistant_id = 56, 
                        course_ids = [
                            56
                            ], 
                        created_at = 56, 
                        engagement = 56, 
                        engagement_opt_out_duration = 56, 
                        engagement_preset = chat_server_connector.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                            created_at = 56, 
                            engagement = 56, 
                            engagement_opt_out_duration = 56, 
                            id = 56, 
                            max_engagement_count = 56, 
                            max_engagement_period = 56, 
                            max_total_engagement_count = 56, 
                            name = '', 
                            order = 56, ), 
                        engagement_preset_id = 56, 
                        id = 56, 
                        interactions_summary = chat_server_connector.models.goal_interactions_summary.GoalInteractionsSummary(
                            is_available = True, 
                            last_engagement_at = 56, 
                            last_opt_out_at = 56, 
                            recent_interaction_count = 56, 
                            total_interaction_count = 56, ), 
                        is_active = True, 
                        is_fullfilled = True, 
                        last_updated_at = 56, 
                        max_engagement_count = 56, 
                        max_engagement_period = 56, 
                        max_total_engagement_count = 56, 
                        name = '', 
                        page_url = '', 
                        primary_course = chat_server_connector.models.course_public.CoursePublic(
                            description = '', 
                            id = 56, 
                            modules = [
                                chat_server_connector.models.course_module_public.CourseModulePublic(
                                    id = 56, 
                                    lessons = [
                                        chat_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                            id = 56, 
                                            title = '', )
                                        ], 
                                    public_description = '', 
                                    short_description = '', 
                                    title = '', )
                                ], 
                            payment_type = 'paid', 
                            title = '', 
                            url = '', ), 
                        primary_course_id = 56, )
                    ],
                id = 56,
                is_active = True,
                is_available = True,
                is_live = True,
                knowledgebase_state = chat_server_connector.models.knowledgebase_state.KnowledgebaseState(
                    course_data = chat_server_connector.models.collection_state.CollectionState(
                        error_message = '', 
                        status = 'unavailable', ), ),
                last_updated_at = 56,
                lexicon_items = [
                    chat_server_connector.models.ai_assistant_lexicon_item.AiAssistantLexiconItem(
                        ai_assistant_id = 56, 
                        deleted_at = 56, 
                        id = 56, 
                        order = 56, 
                        pronounciation = '', 
                        term = '', )
                    ],
                name = '',
                prefer_voice = True,
                system_prompt = '',
                system_prompt_support = '',
                system_prompt_tutor = '',
                voice_id = 56
            )
        else:
            return AiAssistantGet(
                allow_text = True,
                allow_voice = True,
                approved_urls = [
                    ''
                    ],
                banned_keywords = [
                    ''
                    ],
                conversation_style = 'formal',
                created_at = 56,
                function = 'support',
                id = 56,
                is_active = True,
                is_live = True,
                last_updated_at = 56,
                name = '',
                prefer_voice = True,
                voice_id = 56,
        )
        """

    def testAiAssistantGet(self):
        """Test AiAssistantGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
